@@ -10,7 +10,7 @@ from kabaret.subprocess_manager.runner_factory import Runner, logger
 from kabaret.subprocess_manager.flow import RunAction
 
 
-CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json"]
+CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx"]
 CHOICES_ICONS = {
             "blend": ("icons.libreflow", "blender"),
             "kra": ("icons.libreflow", "krita"),
@@ -26,6 +26,7 @@ CHOICES_ICONS = {
             "mp4": ("icons.gui", "youtube-logo"),
             "fbx": ("icons.libreflow", "fbx"),
             "json": ("icons.libreflow", "json"),
+            "jsx": ("icons.libreflow", "jsx"),
         }
 
 
