@@ -357,26 +357,30 @@ class RequestedSiteChoiceValue(flow.values.ChoiceValue):
     _revision = flow.Parent(2)
 
     def choices(self):
-        site_names = []
+        choices = []
+        site_names = self.root().project().get_working_sites().mapped_names()
         
-        for site in self._revision.sync.mapped_items():
-            if site.status.get() == "Available":
-                site_names.append(site.name())
+        for site_name in site_names:
+            sync_status = self._revision.sync[site_name]
+            if sync_status.status.get() == 'Available':
+                choices.append(site_name)
         
-        return site_names
+        return choices
 
 
 class RequestingSiteChoiceValue(flow.values.ChoiceValue):
     _revision = flow.Parent(2)
 
     def choices(self):
-        site_names = []
+        choices = []
+        site_names = self.root().project().get_working_sites().mapped_names()
         
-        for site in self._revision.sync.mapped_items():
-            if site.status.get() == "NotAvailable":
-                site_names.append(site.name())
+        for site_name in site_names:
+            sync_status = self._revision.sync[site_name]
+            if sync_status.status.get() == 'NotAvailable':
+                choices.append(site_name)
         
-        return site_names
+        return choices
 
 
 class RequestAs(flow.Action):
@@ -1074,3 +1078,30 @@ class RequestRevisionsAs(flow.Action):
         self.revision_oids.set("<br>".join(processed_oids))
 
         return self.get_result(close=False)
+
+
+class UploadRevision(flow.Action):
+    
+    _revision = flow.Parent()
+    _revisions = flow.Parent(2)
+    
+    def needs_dialog(self):
+        return False
+    
+    def allow_context(self, context):
+        return context and not self._revision.is_working_copy()
+    
+    def run(self, button):
+        current_site = self.root().project().get_current_site()
+        # Add an upload job for the current site
+        job = current_site.get_queue().submit_job(
+            job_type='Upload',
+            init_status='WAITING',
+            emitter_oid=self._revision.oid(),
+            user=self.root().project().get_user(),
+            studio=current_site.name(),
+        )
+        process_jobs_action = self.root().project().admin.process_jobs
+        process_jobs_action._process(job)
+        
+        self._revisions.touch()
